@@ -24,7 +24,7 @@ class RegistrationForm(forms.Form):
     captcha = CaptchaField(label=_('Type the code below'))
     payment_method = forms.ModelChoiceField(empty_label=None, required=True,
         queryset=PaymentMethod.objects.none(), widget=forms.RadioSelect, initial=1)
-    
+
     def __init__(self, event, user, *args, **kwargs):
         """
         event: instance of Event model
@@ -34,17 +34,17 @@ class RegistrationForm(forms.Form):
         self.event = event
         self.user = user
         self.reg_count = kwargs.pop('reg_count', 0)
-        
+
         super(RegistrationForm, self).__init__(*args, **kwargs)
-        
+
         # no need for captcha if logged in
         if user.is_authenticated():
             self.fields.pop('captcha')
-        
+
         # admin only price override field
         if not user.profile.is_superuser:
             self.fields.pop('amount_for_admin')
-        
+
         reg_conf =  event.registration_configuration
         if reg_conf.can_pay_online:
             payment_methods = reg_conf.payment_method.all()
@@ -52,13 +52,13 @@ class RegistrationForm(forms.Form):
             payment_methods = reg_conf.payment_method.exclude(
                 machine_name='credit card').order_by('pk')
         self.fields['payment_method'].queryset = payment_methods
-        
+
     def get_user(self):
         return self.user
-        
+
     def get_event(self):
         return self.event
-   
+
     def clean_discount(self):
         """
         Returns the discount instance if it exists for a given code.
@@ -89,38 +89,38 @@ class RegistrantForm(forms.Form):
     memberid = forms.CharField(label=_("Member ID"), max_length=50, required=False)
     company_name = forms.CharField(max_length=100, required=False)
     phone = forms.CharField(max_length=20, required=False)
-    
+
     def __init__(self, *args, **kwargs):
         self.pricings = kwargs.pop('pricings')
         self.form_index = kwargs.pop('form_index', None)
-        
+
         super(RegistrantForm, self).__init__(*args, **kwargs)
-        
+
         # make the fields in the subsequent forms as not required
         if self.form_index and self.form_index > 0:
             for key in self.fields.keys():
                 self.fields[key].required = False
-        
+
         # initialize pricing options and reg_set field
         self.fields['pricing'] = forms.ModelChoiceField(widget=forms.HiddenInput, queryset=self.pricings)
-        
+
         allow_memberid = get_setting('module', 'events', 'memberidpricing')
         if not allow_memberid:
             self.fields.pop('memberid')
-        
+
         # initialize internal variables
         self.price = Decimal('0.00')
         self.saved_data = {}
-        
+
     def set_price(self, price):
         self.price = price
-        
+
     def get_price(self):
         return self.price
-        
+
     def get_form_label(self):
         return self.form_index + 1
-        
+
     def get_user(self):
         """
         Gets the user from memberid or email.
@@ -143,47 +143,47 @@ class RegistrantForm(forms.Form):
 
     def clean_first_name(self):
         data = self.cleaned_data['first_name']
-        
+
         # detect markup
         markup_pattern = re.compile('<[^>]*?>', re.I and re.M)
         markup = markup_pattern.search(data)
         if markup:
-            raise forms.ValidationError("Markup is not allowed in the name field")
+            raise forms.ValidationError(_("Markup is not allowed in the name field"))
 
         # detect URL and Email
         pattern_string = '\w\.(com|net|org|co|cc|ru|ca|ly|gov)$'
         pattern = re.compile(pattern_string, re.I and re.M)
         domain_extension = pattern.search(data)
         if domain_extension or "://" in data:
-            raise forms.ValidationError("URL's and Emails are not allowed in the name field")
-        
+            raise forms.ValidationError(_("URL's and Emails are not allowed in the name field"))
+
         data.strip()
         return data
-        
+
     def clean_last_name(self):
         data = self.cleaned_data['last_name']
-        
+
         # detect markup
         markup_pattern = re.compile('<[^>]*?>', re.I and re.M)
         markup = markup_pattern.search(data)
         if markup:
-            raise forms.ValidationError("Markup is not allowed in the name field")
+            raise forms.ValidationError(_("Markup is not allowed in the name field"))
 
         # detect URL and Email
         pattern_string = '\w\.(com|net|org|co|cc|ru|ca|ly|gov)$'
         pattern = re.compile(pattern_string, re.I and re.M)
         domain_extension = pattern.search(data)
         if domain_extension or "://" in data:
-            raise forms.ValidationError("URL's and Emails are not allowed in the name field")
-        
+            raise forms.ValidationError(_("URL's and Emails are not allowed in the name field"))
+
         data.strip()
         return data
-    
+
     def clean_email(self):
         data = self.cleaned_data['email']
         data.strip()
         return data
-    
+
     def _clean_fields(self):
         for name, field in self.fields.items():
             # value_from_datadict() gets the data from the data dictionaries.
@@ -215,5 +215,5 @@ class RegistrantForm(forms.Form):
             already_registered = Registrant.objects.filter(user=user)
             if already_registered:
                 if not user.profile.is_superuser:
-                    raise forms.ValidationError('%s is already registered for this event' % user)
+                    raise forms.ValidationError(_('%s is already registered for this event' % user))
         return data
